# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
🚧 Trying to fix emoji display in windows | [7](https://github.com/laminlabs/lamin-logger/pull/7) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-28 | 0.1.2
💄 Remove vertical bar | [6](https://github.com/laminlabs/lamin-logger/pull/6) | [falexwolf](https://github.com/falexwolf) | 2022-07-24 | 0.1.1
🐛 Quick fix for windows | [3](https://github.com/laminlabs/lamin-logger/pull/3) | [Koncopd](https://github.com/Koncopd) | 2022-07-23 |
🔥 Reduce docs to necessary components | [2](https://github.com/laminlabs/lamin-logger/pull/2) | [falexwolf](https://github.com/falexwolf) | 2022-07-20 |
✨ Added logger and colors | [1](https://github.com/laminlabs/lamin-logger/pull/1) | [sunnyosun](https://github.com/sunnyosun) | 2022-07-20 | 0.1.0
